# Changelog

## Unreleased

## 0.14.0

* [Changed] Use first free label (not the maximum + 1)when new is created

## 0.13.0 

* [Added] Function for computation new size of image after resize

## 0.12.0

* [Added] color resize (and tests for 2D case)

## 0.10.0

* New module geometry3d

## 0.9.0

* New minimize segmentation labels (slab) function

## 0.8.0

* New find list in lists function

## 0.7.0

* Modules reorganization with back compatibility
* New function for getting unique labels by seeds

## 0.6.0

* New function for connected labels
* More tests
* New API for neighbor list function


## 0.5.0

* Get neighbors function
* Cooccurrence matrix with faster calculation if no counts required
* New neighborhood function implemented
* Many new tests
* Faster implementation of max_area_index

## 0.3.0

* cooccurrence matrix
